import { Component, Mixins, Vue, Watch } from 'vue-property-decorator'
import {
    State,
    Getter,
    Action,
    Mutation,
} from "vuex-class";
import Types from "@/views/admin/store/types";
import { Route, RouteRecord } from "vue-router";
import { Menu } from "view-design";
import HomeParent, { BreadItem } from "@/views/home/Common/HomeParent";
import {  MenuInterface,  } from "@/views/home/Common/Types";
import store from "@/views/home/store";
import { Request } from "@/utils/Request";
import Url from "@/utils/Url";
import {Message} from "element-ui";



@Component
export default class Layout extends HomeParent {

    public siteLogo: object = {}
    public siteMarquee: object[] = [];
    public visible: boolean = false;
    public myMenus: MenuInterface[] = [];
    public routes: BreadItem[] = [];



    public created() {
        this._getMyMenu()
    }

    @Watch("$route", {immediate: true, deep: true})
    private _watchRoute(route: Route): void {
        this.routes.length = 0;
        route.matched.forEach((item: RouteRecord) => {
            let ret: BreadItem = this.$router.resolve({name: item.name, params: route.params});
            ret.name = item.meta.title;
            this.routes.push(ret);
            // console.log(ret);
        });
    }


    public get isLogin() {
        return this.$store.state.user.token.length > 0;
    }

    public onDropdownEvent(name: string): void {
        switch (name) {
            case "logout" : this.logout();break;
            case "updateName" : this.updateName();break;
        }
    }

    public async logout() {
        const  res:any = await Request('get',Url.LOGOUT)
        if (res.code == 200){
            store.commit('del_token')
            this.goPage("login");
        }else {
            Message({
                message: res.message,
                type: 'error',
                duration: 2 * 1000
            })
        }
    }
    public  updateName(){
        let self = this;
        this.$Modal.confirm({
            title:"修改昵称",
            render: function(h) {
                return h('Input', {
                    props: {
                        value: self.$store.getters.user.name,
                        autofocus: true,
                        placeholder: 'Please enter your nickName...'
                    },
                    on: {
                        input: (val) => {
                            this.value = val;
                        }
                    }
                })
            },
            onOk :function() {
                self.onVisibleChange(true)
                if (!this.value || this.value == self.$store.getters.user.name || this.value == '') {
                    return;
                }
                let data = {nickname:this.value};
                Request('get', Url.UPDATE_NICKNAME,data).then((res:any)=>{
                    if (res.code == 200){
                        self.success()
                    }else {
                        self.error(res.message)
                    }
                })
            }
        })


    }



    /**
     * 跳转页面时关闭dropdown
     * @param name
     */
    public onMenuChange(name): void {
        this.visible = false;
    }

    /**
     * 切换dropdown显示状态
     * @param st
     */
    public onVisibleChange(st: boolean) : void {
        this.visible = !this.visible;
    }


    private _getMyMenu() {
        Request('get', Url.MY_MENU).then((res:any)=>{
            if (res.code == 200){
                this.myMenus =  this._parseTreeData(res.data);
            }
        })
    }



    private _parseTreeData(list: any[]) {
        return list.map((item: any) => {
            if (item.children.length > 0) {
                item._showChildren = true;
                item.children = this._parseTreeData(item.children);
            }
            return item
        });
    }

    private _updateRoutes(name: string, idx: number): void {
        if (this.routes.length >= idx - 1) {
            this.routes[idx].name = name;
        }
    }
}