import {Component, Mixins, Vue, Watch} from 'vue-property-decorator'
import {
    State,
    Getter,
    Action,
    Mutation
} from "vuex-class";
import HomeParent from "@/views/home/Common/HomeParent";
import CustomPage from "@/components/page.vue";
import SvgIcon from '@/components/SvgIcon.vue'
import {TableColumn} from "view-design"
import {ExcelExport, Request} from "@/utils/Request";
import Url from "@/utils/Url";


@Component({
    components: {
        SvgIcon, CustomPage
    }
})
export default class Nft extends HomeParent {
    name: string = 'nft'
    public List: any = []
    public columns: TableColumn[] = [{
        title: "token_id",
        key: 'token_id',
    }, {
        title: "creator",
        key: "creator_address"
    }, {
        title: "owner",
        key: "owner_address"
    },{
        title: "type",
        key: "token_type",
        width:80
    },{
        title: "state",
        key: "token_state",
        width:80
    }, {
        title: "item",
        key: "item_id"
    }, {
        title: "confirm_count",
        key: "confirm_count",
    },{
        title: "confirm_number",
        key: "confirm_block_number"
    }, {
        title: "create_time",
        key: "createtime"
    }, {
        title: "操作",
        width:120,
        slot: "operation"
    }
    ]
    public showNftDialog:boolean = false;
    public nftDetail:any='';
    public total: number = 0;
    public search: { page: number, size: number, token_id?: string,creator?: string ,owner?:string,time?:any} = {
        page: 1, size: 10
    }

    public created() {
        this._getData()
    }

    public searchEvent(){
        this._getData()
    }

    public   exportEvent(){
        ExcelExport(Url.EXPORTS,{name:'nft'}).then(res=>{
            this.convertRes2Blob(res,'nft')
        })

    }

    public changeTime(time){
        this.search.time = time
    }

    @Watch("search.page")
    private _onPageChange(): void {
        this._getData()
    }

    @Watch("search.size")
    private _onPageSizeChange(): void {
        this.search.page = 1;
        this._getData()
    }

    public async showNft(idx){
        this.showNftDialog = true;
        const res = await Request('get', Url.NFT_SHOW, {idx})
        this.nftDetail = res.data
    }


    private async _getData() {
        const res:any = await Request('get', Url.NFT, this.search)
        if (res.code!=200){
            this.error(res.message)
            return
        }
        this.List = res.data.data
        this.total = res.data.total
    }


}