import { Component, Mixins, Vue, Watch } from 'vue-property-decorator'
import Url from "@/utils/Url";
import {
    State,
    Getter,
    Action,
    Mutation
} from "vuex-class";
import HomeParent from "@/views/home/Common/HomeParent";
import { NodeInterface } from "@/views/home/Common/Types";
import CustomPage from "@/components/page.vue";
import { TableColumn ,Form} from "view-design";
import {Request} from "@/utils/Request";
import {Message} from "element-ui";

@Component({
    components : {
        CustomPage
    }
})
export default class Node extends HomeParent {
    name : string = "node";
    public dialogFormVisible: boolean = false;
    public isEdit : boolean = false;
    public drawerTitle:string = '';
    public form: any = {
        name : null, action : null, controller : null, pid : null
    }
    public rules: object = {
        name : [{required : true, trigger : "blur", "message" : "请填写权限名称"}],
        pid : [{required : true, trigger : "selected", "message" : "请选择父级权限"}],
        action : [{required : true, trigger : "blur", "message" : "请填写控制器方法"}],
        controller : [{required : true, trigger : "blur", "message" : "请填写控制器名称"}],
    }
    public node : NodeInterface[] = [];
    public columns :  any = [ {
        title : "名称",
        key : "name",
        tree: true
    }, {
        title : "控制器",
        key : "controller",
    }, {
        title : "方法",
        key : "action"
    }, {
        title : "操作",
        slot : "operation"
    }];

    public created() : void {
        this._getData();
    }

    public addNode(){
        this.drawerTitle = '新增权限'
        this.isEdit = false;
        this._initForm()
        this.dialogFormVisible = true
    }
    public  saveNode(){
        let form : Form = this.$refs["dataForm"] as Form;
         form.validate((valid : boolean) => {
            if (!valid) {
                return;
            }
            this._saveNode();
        })
    }

    public cancel(){
        this.dialogFormVisible = false
        let form : Form = this.$refs['dataForm'] as Form;
        form.resetFields();
    }

    public editNode(row : NodeInterface) : void {
        this.drawerTitle = '修改权限'
        this.isEdit = true;
        this.form = {name : row.name, action : row.action, controller : row.controller, pid : row.pid,id:row.id};
        this.dialogFormVisible = true
    }

    public updateNode(){
        let form : Form = this.$refs["dataForm"] as Form;
        form.validate((valid : boolean) => {
            if (!valid) {
                return;
            }
            this._saveNode();
        })
    }

    public deleteNode(row : NodeInterface) : void {
        let url = this.$sprintf(Url.DELETE_NODE, row.id);
        this.doDeleteItem("", () => {
            Request('delete', url).then((res:any)=>{
                if (res.code == 200){
                    this._getData();
                    this.success()
                }else {
                    this.error(res.message)
                }
            })
        })
    }

    private _saveNode(){
        let url : string = Url.NODE;
        let method  = 'post';
        if (this.isEdit){
            method = 'put';
            url = this.$sprintf(Url.UPDATE_NODE, this.form.id);
        }
        Request(method, url,this.form).then((res:any)=>{

            if (res.code == 200){
                this.dialogFormVisible = false
                this._initForm()
                this._getData();
                this.success()
            }else {
                this.error()
            }
        })
    }

    private async _getData()  {
        const res:any = await Request('get', Url.NODE)
        if (res.code == 200){
            this.node = this._parseTreeData(res.data)
        }else {
            console.log(res.message)
            this.error(res.message)
        }

    }

    public styles () {
        return  {
            height: 'calc(100% - 55px)',
            overflow: 'auto',
            paddingBottom: '53px',
            position: 'relative'
        }
    }

    private _parseTreeData(list : any[]) {
        return list.map((item : any) => {
            if (item.children.length > 0) {
                item._showChildren = true;
                item.children = this._parseTreeData(item.children);
            }
            return item
        });
    }
    private _initForm() {
        this.form = {name : null, action : null, controller : null, pid : null}
    }
}