import Vue from 'vue'
import Vuex from 'vuex'
import user, { UserState } from "@/views/home/store/user";
import createPersistedState from 'vuex-persistedstate'

Vue.use(Vuex)

interface StateInterface {
    user : UserState,
}

const localStorage : any = window.localStorage;

export default new Vuex.Store({
    getters : {
        token : (state : StateInterface) => state.user.token,
        user : (state : StateInterface) => state.user.user,
        nonce:state => state.nonce
    },
    modules : {
        user
    },
    plugins : [
        createPersistedState({
            key : 'home',
            storage : {
                getItem : (key : string) => {
                    return localStorage.getItem(key);
                },
                setItem : (key : string, value : any) => {
                    return localStorage.setItem(key, value);
                },
                removeItem : (key : string) => {
                    return localStorage.removeItem(key);
                }
            }
        })
    ],
    mutations: {
        set_nonce(state, nonce) {
            state.nonce = nonce
            // sessionStorage.nonce = nonce
        },
        del_nonce(state) {
            state.nonce = ''
            // sessionStorage.nonce = nonce
        },
        set_token(state, token) {
            state.token = token
            // sessionStorage.token = token
        },
        del_token(state) {
            state.token = ''
            // sessionStorage.removeItem('token')
        }
    }
})
